package com.hw.mes.mapper;

import java.util.List;
import com.hw.mes.domain.MesProjectInfo;

/**
 * 项目信息Mapper接口
 * 
 * @author Yinq
 * @date 2024-02-19
 */
public interface MesProjectInfoMapper 
{
    /**
     * 查询项目信息
     * 
     * @param projectId 项目信息主键
     * @return 项目信息
     */
    public MesProjectInfo selectMesProjectInfoByProjectId(Long projectId);

    /**
     * 查询项目信息列表
     * 
     * @param mesProjectInfo 项目信息
     * @return 项目信息集合
     */
    public List<MesProjectInfo> selectMesProjectInfoList(MesProjectInfo mesProjectInfo);

    /**
     * 新增项目信息
     * 
     * @param mesProjectInfo 项目信息
     * @return 结果
     */
    public int insertMesProjectInfo(MesProjectInfo mesProjectInfo);

    /**
     * 修改项目信息
     * 
     * @param mesProjectInfo 项目信息
     * @return 结果
     */
    public int updateMesProjectInfo(MesProjectInfo mesProjectInfo);

    /**
     * 删除项目信息
     * 
     * @param projectId 项目信息主键
     * @return 结果
     */
    public int deleteMesProjectInfoByProjectId(Long projectId);

    /**
     * 批量删除项目信息
     * 
     * @param projectIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMesProjectInfoByProjectIds(Long[] projectIds);
}
